#!/usr/bin/env node

const { execSync } = require('child_process');
const path = require('path');
const fs = require('fs');
const readlineSync = require('readline-sync');

const runCommand = (command, options = {}) => {
  try {
    execSync(command, { stdio: 'inherit', ...options });
  } catch (err) {
    console.error(`Failed to execute command: ${command}`);
    console.error('Error details:', err);
    process.exit(1);
  }
};

const updatePackageJson = (projectName, repoName) => {
  const packageJsonPath = path.join(projectName, 'package.json');
  const packageJson = JSON.parse(fs.readFileSync(packageJsonPath, 'utf8'));

  // Prompt user for additional details
  packageJson.name = readlineSync.question(`Enter package name (or press Enter to keep current, default is '${repoName}'): `) || repoName;
  packageJson.repository = readlineSync.question('Enter repository URL: ');
  packageJson.description = readlineSync.question('Enter project description: ');
  packageJson.homepage = readlineSync.question('Enter homepage URL: ');
  packageJson.license = readlineSync.question('Enter license: ');
  packageJson.author = readlineSync.question('Enter author: ');

  // Write updated package.json
  fs.writeFileSync(packageJsonPath, JSON.stringify(packageJson, null, 2));

  // Print a summary
  console.log('\nSummary of package.json:');
  console.log(`  Name: ${packageJson.name}`);
  console.log(`  Repository: ${packageJson.repository}`);
  console.log(`  Description: ${packageJson.description}`);
  console.log(`  Homepage: ${packageJson.homepage}`);
  console.log(`  License: ${packageJson.license}`);
  console.log(`  Author: ${packageJson.author}`);
};

const createNextjsApp = (projectName) => {
  const repoName = projectName || 'my-nextjs-app'; // Default to a name if not provided
  const templateRepoURL = 'https://github.com/muhammad-fiaz/nextjs-app.git'; // Corrected the template repository URL

  const projectDir = path.resolve(process.cwd(), repoName);

  // Check if the directory already exists
  if (fs.existsSync(projectDir)) {
    console.error(`Error: Directory '${repoName}' already exists.`);
    console.error('Choose a different project name or delete the existing directory.');
    process.exit(1);
  }

  const gitCheckoutCommand = `git clone --depth=1 ${templateRepoURL} "${repoName}"`;
  const installDepsCommand = `cd "${repoName}" && npm install`;
  const gitRemoveCommand = process.platform === 'win32' ? `cd ${repoName} && rmdir /s /q .git` : `cd ${repoName} && rm -rf .git`;

  console.log(`Creating a new Next.js app in ${repoName}...`);
  runCommand(gitCheckoutCommand);

  // Update package.json with user input
  updatePackageJson(repoName, projectName);

  console.log(`Installing dependencies for ${repoName}...`);
  runCommand(installDepsCommand);

  console.log(`Finalizing for ${repoName}...`);
  runCommand(gitRemoveCommand);

  console.log('Congrats! Your new Next.js app is ready!');
  console.log(`cd "${repoName}" && npm run dev`);
};

// Get the project name from the command line argument
const projectName = process.argv[2];

// Call the function to create the Next.js app
createNextjsApp(projectName);
